@@ -1,16 +1,15 @@
 from datetime import datetime
 
-from bs4 import BeautifulSoup as bs
-from loguru import logger
 import numpy as np
 import pandas as pd
 import requests
+from bs4 import BeautifulSoup as bs
+from loguru import logger
 from requests.adapters import HTTPAdapter
 from tqdm import tqdm
 from urllib3.util import Retry
 from user_agent import generate_user_agent
 
-
 # A public league for current week and player IDs
 PUBLIC_LEAGUE = 76554
 
@@ -19,6 +18,9 @@ def create_session():
     """Create requests session with retries and random user-agent"""
     s = requests.Session()
     s.headers = {
+        "Accept": "text/html",
+        "Accept-Encoding": "gzip, deflate, br",
+        "Accept-Language": "en-US",
         "Content-Type": "application/x-www-form-urlencoded;charset=utf-8",
         "User-Agent": generate_user_agent(),
     }
